@@ -69,7 +69,8 @@ I915DisplayVideoTextured(ScrnInfoPtr scrn,
 		ScreenPtr screen = pixmap->drawable.pScreen;
 
 		target = screen->CreatePixmap(screen,
-					      drw_w, drw_h,
+					      dstRegion->extents.x2 - dxo,
+					      dstRegion->extents.y2 - dyo,
 					      pixmap->drawable.depth,
 					      CREATE_PIXMAP_USAGE_SCRATCH);
 
